@@ -1,6 +1,6 @@
 ;; merlin/pager.jl -- a bad pager
 
-;; version -0.91.2
+;; version -0.91.3
 
 ;; Copyright (C) 2000-2001 merlin <merlin@merlin.org>
 
@@ -294,7 +294,11 @@
                 (height . ,(cdr dim)))))))))
 
   (define (after-add-window-eye pager window)
-    (unless (or (window-get window 'ignored) (window-get window (sawlet-symbol pager 'win))) ;; HACK
+    (unless
+        (or (window-get window 'ignored)
+            (dock-window-p window)
+            (desktop-window-p window)
+            (window-get window (sawlet-symbol pager 'win))) ;; HACK
       (let*
 	  ((border (win-foo pager window 'win-border))
            (win
