@@ -1,6 +1,6 @@
 ;; merlin/sawlet.jl -- a bad saw(fish app)let framework
 
-;; version -0.4.2
+;; version -0.4.3
 
 ;; Copyright (C) 2000-2001 merlin <merlin@merlin.org>
 
@@ -94,6 +94,12 @@
     :group sawlets
     :after-set (lambda () (define-default-sawlet-placement-mode)))
 
+  (defcustom merlin.sawlet:default-placement:avoid t
+    "Default placement avoids panels, etc."
+    :type boolean
+    :group sawlets
+    :after-set (lambda () (define-default-sawlet-placement-mode)))
+
   (define (syms symbol . rest)
     (intern
       (apply concat
@@ -306,7 +312,8 @@
   (define (define-default-sawlet-placement-mode)
     (define-sawlet-placement-mode 'sawlet
       merlin.sawlet:default-placement:origin
-      merlin.sawlet:default-placement:direction))
+      merlin.sawlet:default-placement:direction
+      merlin.sawlet:default-placement:avoid))
 
   (define-default-sawlet-placement-mode)
 
@@ -447,5 +454,6 @@
                         '(sticky . t)
                         '(sticky-viewport . t)
                         '(window-list-skip . t)
+                        '(task-list-skip . t)
                         '(skip-tasklist . t)
                         '(frame-type . border-only))))
